/**
 Find a linear ranking function for the program

 x' >= 0.9 + 0.2*x &
 x' <= 1.1 + 0.2*x &
 x >= 0 &
 x <= 4

 (There is no linear ranking function if the program operates on the
  rationals. Over the integers, the program is equivalent to x=0 &
  x'=1, for which simple ranking functions exist. This shows that the
  approach by Podelski and Rybalchenko is incomplete over the
  integers.)

  */

\existentialConstants {
  // the lambda-witness vectors

  int l_11_1;
  int l_11_2;
  int l_11_3;
  int l_11_4;

  int l_12_1;
  int l_12_2;
  int l_12_3;
  int l_12_4;

  int rankingCoeff1;
  int lowerBound1;
}

\problem {
//   l_i1 Ai' = 0

  l_11_1 * -1 + l_11_2 * 1 + l_11_3 * 0 + l_11_4 * 0 = 0
&

//   (l_i1 - l_i2) Ai = 0

  (l_11_1 - l_12_1) * 2 + (l_11_2 - l_12_2) * -2 + (l_11_3 - l_12_3) * -10 +
  (l_11_4 - l_12_4) * 10 = 0
&  

//   l_i2 (Ai + Ai') = 0

  l_12_1 * (2 + -10) + l_12_2 * (-2 + 10) + l_12_3 * (-10 + 0) + l_12_4 * (10 + 0) = 0
&

//   l_i2 bi < 0

  l_12_1 * -9 + l_12_2 * 11 + l_12_3 * 0 + l_12_4 * 40 < 0
&

//   l_12 A1' = l_22 A2'

  rankingCoeff1 = l_12_1 * -10 + l_12_2 * 10 + l_12_3 * 0 + l_12_4 * 0
&

  lowerBound1 = -(l_11_1 * -9 + l_11_2 * 11 + l_11_3 * 0 + l_11_4 * 40)
&

//   l_s non-negative

  l_11_1 >= 0 &
  l_11_2 >= 0 &
  l_11_3 >= 0 &
  l_11_4 >= 0 &
  l_12_1 >= 0 &
  l_12_2 >= 0 &
  l_12_3 >= 0 &
  l_12_4 >= 0
}